@@ -49,29 +49,56 @@
 #' grid$noise <- gen_perlin(grid$x, grid$y)
 #' plot(grid, noise)
 #'
-noise_perlin <- function(dim, frequency = 0.01, interpolator = 'quintic',
-                   fractal = 'fbm', octaves = 3, lacunarity = 2, gain = 0.5,
-                   pertubation = 'none', pertubation_amplitude = 1) {
-  interpolator <- match.arg(interpolator, interpolators)
+noise_perlin <- function(
+  dim,
+  frequency = 0.01,
+  interpolator = 'quintic',
+  fractal = 'fbm',
+  octaves = 3,
+  lacunarity = 2,
+  gain = 0.5,
+  pertubation = 'none',
+  pertubation_amplitude = 1
+) {
+  interpolator <- arg_match0(interpolator, interpolators)
   interpolator <- match(interpolator, interpolators) - 1L
-  fractal <- match.arg(fractal, fractals)
+  fractal <- arg_match0(fractal, fractals)
   fractal <- match(fractal, fractals) - 1L
-  pertubation <- match.arg(pertubation, pertubations)
+  pertubation <- arg_match0(pertubation, pertubations)
   pertubation <- match(pertubation, pertubations) - 1L
 
   if (length(dim) == 2) {
-    noise <- perlin_2d_c(dim[1], dim[2], seed = sample(.Machine$integer.max, size = 1),
-                freq = frequency, interp = interpolator, fractal = fractal,
-                octaves = octaves, lacunarity = lacunarity, gain = gain,
-                pertube = pertubation, pertube_amp = pertubation_amplitude)
+    noise <- perlin_2d_c(
+      dim[1],
+      dim[2],
+      seed = sample(.Machine$integer.max, size = 1),
+      freq = frequency,
+      interp = interpolator,
+      fractal = fractal,
+      octaves = octaves,
+      lacunarity = lacunarity,
+      gain = gain,
+      pertube = pertubation,
+      pertube_amp = pertubation_amplitude
+    )
   } else if (length(dim) == 3) {
-    noise <- perlin_3d_c(dim[1], dim[2], dim[3], seed = sample(.Machine$integer.max, size = 1),
-                freq = frequency, interp = interpolator, fractal = fractal,
-                octaves = octaves, lacunarity = lacunarity, gain = gain,
-                pertube = pertubation, pertube_amp = pertubation_amplitude)
+    noise <- perlin_3d_c(
+      dim[1],
+      dim[2],
+      dim[3],
+      seed = sample(.Machine$integer.max, size = 1),
+      freq = frequency,
+      interp = interpolator,
+      fractal = fractal,
+      octaves = octaves,
+      lacunarity = lacunarity,
+      gain = gain,
+      pertube = pertubation,
+      pertube_amp = pertubation_amplitude
+    )
     noise <- array(noise, dim)
   } else {
-    stop('Perlin noise only supports two or three dimensions', call. = FALSE)
+    cli::cli_abort('Perlin noise only supports two or three dimensions')
   }
   noise
 }
@@ -82,12 +109,21 @@ noise_perlin <- function(dim, frequency = 0.01, interpolator = 'quintic',
 #' used
 #' @param ... ignored
 #' @export
-gen_perlin <- function(x, y = NULL, z = NULL, frequency = 1, seed = NULL,
-                       interpolator = 'quintic', ...) {
+gen_perlin <- function(
+  x,
+  y = NULL,
+  z = NULL,
+  frequency = 1,
+  seed = NULL,
+  interpolator = 'quintic',
+  ...
+) {
   dims <- check_dims(x, y, z)
-  interpolator <- match.arg(interpolator, interpolators)
+  interpolator <- arg_match0(interpolator, interpolators)
   interpolator <- match(interpolator, interpolators) - 1
-  if (is.null(seed)) seed <- random_seed()
+  if (is.null(seed)) {
+    seed <- random_seed()
+  }
   frequency <- as.numeric(frequency)
   seed <- as.integer(seed)
   if (is.null(z)) {
