@@ -20,7 +20,14 @@
 #'
 #' plot(grid, chess)
 #'
-gen_checkerboard <- function(x, y = NULL, z = NULL, t = NULL, frequency = 1, ...) {
+gen_checkerboard <- function(
+  x,
+  y = NULL,
+  z = NULL,
+  t = NULL,
+  frequency = 1,
+  ...
+) {
   dims <- check_dims(x, y, z, t)
   all <- floor(dims$x * frequency) +
     floor((dims$y %||% 0) * frequency) +
